@@ -1,8 +1,3 @@
-.infConstant <- function(k=NULL){
-  v <- mim.cmd(paste("InfConstant", k),look.nice=FALSE)
-  v <- as.numeric(v[length(v)])
-  return(v)
-}
 
 
 stepwise <- function(x,arg=NULL,critlevel=NULL,infconstant=NULL) UseMethod("stepwise")
@@ -12,40 +7,37 @@ stepwise.mim <- function(x,arg=NULL,critlevel=NULL,infconstant=NULL){
     ##mim.out <- mim.cmd(paste("stepwise ", options, collapse=''), look.nice=!short)
     mim.cmd(paste("# stepwise ", options, collapse=''), return.look.nice=TRUE)
     mim.out <- mim.cmd(paste("stepwise ", options, collapse=''), return.look.nice=TRUE)
-    ##mo<<-print (mim.out)
-#     index   <- min(grep("Selected", mim.out))
-#     print(index)
-#     if (short){
-#       value.str <- paste( mim.out[-(1:(index-1))], collapse=' ')
-#       cat(value.str,fill=TRUE)
-#     }
-#     value     <- mim.out[-(1:(index+1))]
-#    return(invisible(value))
   }
 
   fit(x)
 
   if (!is.null(critlevel)){
     str <- paste("CritLevel ", critlevel)
-    mim.cmd (print(str))
+    mim.cmd (str)
   }
 
   oldic <- .infConstant()
-    if (!is.null(infconstant))    .infConstant(infconstant)
+  if (!is.null(infconstant))
+    .infConstant(infconstant)
   .stepwiseMIM(arg)
-  if (!is.null(infconstant))    .infConstant(oldic)
+  if (!is.null(infconstant))
+    .infConstant(oldic)
 
-
-  rsm <- .RSmodel()
+  rsm  <- .RSmodel()
   mimFormula.letter <- rsm$Formula.as.string
-  d <- x$data
-  l <- string2listLetters(mimFormula.letter)
-  a <- src2tgt(l, src=d$letter, tgt=d$name)
+  d    <- x$data
+  l    <- string2listLetters(mimFormula.letter)
+  a    <- src2tgt(l, src=shortNames(d), tgt=varNames(d))
   mimFormulaNames <- list2stringNames(a)
 
   return(mim(mimFormulaNames, data=x$data))
 }
 
+.infConstant <- function(k=NULL){
+  v <- mim.cmd(paste("InfConstant", k),look.nice=FALSE)
+  v <- as.numeric(v[length(v)])
+  return(v)
+}
 
 fixSet <- function(v=NULL,mim=NULL){
  .fixDefault(v,"set",mim)
